==> jupyterlab_tensorboard_pro-0.3.1.tgz: package/lib/biz/tab.js <==
import React, { useState, useEffect, useRef } from 'react';
import { Button } from '@blueprintjs/core/lib/esm/components/button/buttons';
import { MenuItem } from '@blueprintjs/core/lib/esm/components/menu/menuItem';
import { InputGroup } from '@blueprintjs/core/lib/esm/components/forms/inputGroup';
import { Switch } from '@blueprintjs/core/lib/esm/components/forms/controls';
import { Tag } from '@blueprintjs/core/lib/esm/components/tag/tag';
import { toArray } from '@lumino/algorithm';
import classNames from 'classnames';
import { Select } from '@blueprintjs/select';
import { PageConfig } from '@jupyterlab/coreutils';
import { showDialog, Dialog } from '@jupyterlab/apputils';
import { Loading } from './loading';
import { Tensorboard } from '../tensorboard';
import { DEFAULT_REFRESH_INTERVAL } from '../consts';
const TensorboardCreator = (props) => {
    const [logDir, setLogDir] = useState(props.getCWD());
    const [reloadInterval, setReloadInterval] = useState(DEFAULT_REFRESH_INTERVAL);
    const [enableReloadInterval, setEnableReloadInterval] = useState(true);
    return (React.createElement("div", { className: "tensorboard-ng-creator" },
        React.createElement("div", { className: "tensorboard-ng-config" },
            React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                React.createElement("label", { title: "Path relative to workspace, don\\'t start with `/`" },
                    React.createElement("strong", null, "Log Dir")),
                React.createElement(InputGroup, { style: { width: 160 }, small: true, placeholder: "Enter your log dir...", value: logDir, onChange: e => {
                        setLogDir(e.target.value);
                    } })),
            React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                React.createElement(Switch, { className: "interval-switch", checked: enableReloadInterval, onChange: () => {
                        setEnableReloadInterval(!enableReloadInterval);
                    }, labelElement: React.createElement("strong", { title: "Setting reload interval may cause additional burden on the jupyter backend" }, "Enable Reload Interval") }),
                enableReloadInterval && (React.createElement(InputGroup, { style: { width: 80 }, small: true, placeholder: "Enter your reload_interval ...", value: enableReloadInterval ? `${reloadInterval}` : '', onChange: e => {
                        setReloadInterval(Number(e.target.value));
                    }, rightElement: React.createElement(Tag, { minimal: true }, "s"), type: "number" })))),
        React.createElement("div", { className: "tensorboard-ng-ops create" },
            React.createElement(Button, { small: true, intent: "warning", className: "tensorboard-ng-op-btn", onClick: () => {
                    props.startTensorBoard(logDir, enableReloadInterval ? reloadInterval : 0);
                }, disabled: props.disable }, "Create TensorBoard")),
        React.createElement("div", { className: "tensorboard-ng-expand" }),
        React.createElement(Button, { small: true, outlined: true, icon: "help", onClick: () => {
                props.openDoc();
            } }, "Document")));
};
const ModelSelector = Select.ofType();
const useRefState = (initValue) => {
    const [value, setValue] = useState(initValue);
    const valueRef = useRef(value);
    const updateValue = (value) => {
        setValue(value);
        valueRef.current = value;
    };
    return [value, valueRef, updateValue];
};
export const TensorboardTabReact = (props) => {
    const [ready, readyRef, updateReady] = useRefState(false);
    const [createPending, createPendingRef, updateCreatePending] = useRefState(false);
    const [reloadPending, reloadPendingRef, updateReloadPending] = useRefState(false);
    const [showNewRow, setShowNewRow] = useState(false);
    const [showListStatus, setShowListStatus] = useState(false);
    const [currentTensorBoard, setCurrentTensorBoard] = useState(null);
    const currentTensorBoardRef = useRef(currentTensorBoard);
    const updateCurrentTensorBoard = (model) => {
        props.updateCurrentModel(model);
        setCurrentTensorBoard(model);
        currentTensorBoardRef.current = model;
    };
    const [runningTensorBoards, setRunningTensorBoards] = useState([]);
    // currently inactive
    const [notActiveError, setNotActiveError] = useState(false);
    const currentLoading = reloadPending || createPending;
    const refreshRunning = () => {
        if (createPendingRef.current || reloadPendingRef.current) {
            return;
        }
        props.tensorboardManager.refreshRunning().then(() => {
            const runningTensorboards = [...toArray(props.tensorboardManager.running())];
            // hint: Using runningTensorboards directly may cause setState to fail to respond
            const modelList = [];
            for (const model of runningTensorboards) {
                modelList.push(model);
            }
            setRunningTensorBoards(modelList);
            if (readyRef.current) {
                // 如果不是第一次了
                if (currentTensorBoardRef.current) {
                    if (!modelList.find(model => model.name === currentTensorBoardRef.current.name)) {
                        setNotActiveError(true);
                    }
                }
                else {
                    // do nothing
                    // Maybe not at the beginning, the user planned to create a new one later, and then did not create a new one. At this time, he found that there was
                }
                return;
            }
            const model = props.createdModelName
                ? modelList.find(model => model.name === props.createdModelName)
                : modelList[0];
            if (model) {
                updateCurrentTensorBoard(model);
                setShowListStatus(true);
            }
            else {
                setShowNewRow(true);
                setShowListStatus(false);
            }
            updateReady(true);
        });
    };
    const startTensorBoard = (logDir, reloadInterval) => {
        if (Number.isNaN(reloadInterval) || reloadInterval < 0) {
            return showDialog({
                title: 'Param Check Failed',
                body: 'reloadInterval should > 0 when enabled',
                buttons: [Dialog.okButton()]
            });
        }
        updateCreatePending(true);
        const currentName = currentTensorBoard === null || currentTensorBoard === void 0 ? void 0 : currentTensorBoard.name;
        props.tensorboardManager
            .startNew(logDir, reloadInterval)
            .then(tb => {
            if (currentName === tb.model.name) {
                showDialog({
                    body: 'Existing tensorBoard for the logDir will be reused directly',
                    buttons: [Dialog.okButton()]
                });
            }
            updateCurrentTensorBoard(tb.model);
            updateCreatePending(false);
            refreshRunning();
            setShowListStatus(true);
            setShowNewRow(false);
        })
            .catch(e => {
            showDialog({
                body: 'Start TensorBoard internal error',
                buttons: [Dialog.okButton()]
            });
        });
    };
    // hint: Because we are simulating reload here, the tab component cannot listen to runningChanged
    const reloadTensorBoard = () => {
        // There was no reload in the world, so I had to stop and restart to simulate reload
        if (!currentTensorBoard) {
            return;
        }
        updateReloadPending(true);
        updateCurrentTensorBoard(null);
        const reloadInterval = typeof currentTensorBoard.reload_interval === 'number'
            ? currentTensorBoard.reload_interval
            : DEFAULT_REFRESH_INTERVAL;
        const currentLogDir = currentTensorBoard.logdir;
        const errorCallback = (e) => {
            showDialog({
                title: 'TensorBoard Reload Error',
                body: 'The panel has been closed, you can reopen to create new',
                buttons: [Dialog.okButton()]
            });
            props.closeWidget();
        };
        try {
            props.tensorboardManager
                .shutdown(currentTensorBoard.name)
                .then(res => {
                props.tensorboardManager
                    .startNew(currentLogDir, reloadInterval)
                    .then(res => {
                    refreshRunning();
                    updateReloadPending(false);
                    updateCurrentTensorBoard(currentTensorBoard);
                })
                    .catch(e => {
                    errorCallback(e);
                });
            })
                .catch(e => {
                errorCallback(e);
            });
        }
        catch (e) {
            errorCallback(e);
        }
    };
    const destroyTensorBoard = () => {
        props.tensorboardManager.shutdown(currentTensorBoard.name).then(res => {
            props.closeWidget();
        });
    };
    const copyTensorBoard = () => {
        if (!currentTensorBoard) {
            return;
        }
        props.openTensorBoard(currentTensorBoard.name, true);
    };
    const formatDir = (dir) => {
        const pageRoot = PageConfig.getOption('serverRoot');
        if (pageRoot && dir.indexOf(pageRoot) === 0) {
            let replaceResult = dir.replace(pageRoot, '');
            if (replaceResult === '') {
                replaceResult = '/';
            }
            return `WORKSPACE${replaceResult}`;
        }
        return dir;
    };
    const getShowName = (model) => {
        const formattedDir = formatDir(model.logdir);
        return `${model.name} - ${formattedDir}`;
    };
    const changeModel = (model) => {
        if (currentTensorBoard.name === model.name) {
            return;
        }
        setCurrentTensorBoard(model);
    };
    const toggleNewRow = () => {
        setShowNewRow(!showNewRow);
    };
    const openInNewTab = () => {
        window.open(Tensorboard.getUrl(currentTensorBoard.name));
    };
    useEffect(() => {
        refreshRunning();
        const refreshIntervalId = setInterval(refreshRunning, 30 * 1000);
        return () => {
            clearInterval(refreshIntervalId);
        };
    }, []);
    const getBlankContent = () => {
        if (!ready) {
            return React.createElement(Loading, { title: "initializing" });
        }
        else if (createPending) {
            return (React.createElement(Loading, { title: "TensorBoard is initializing", desc: "This stage may take a long time (the more content in the directory, the longer it will be)" }));
        }
        else if (reloadPending) {
            return (React.createElement(Loading, { title: "TensorBoard is reloading", desc: "This stage may take a long time (the more content in the directory, the longer it will be)" }));
        }
        else {
            return (React.createElement("div", { className: "common-tip" },
                React.createElement("p", { className: "title" }, "No instance yet, please create a new TensorBoard"),
                React.createElement("p", { className: "desc" },
                    React.createElement("i", null, "If the selected log directory has too much content, tensorboard initialization may take a long time, during which jupyter will get stuck"))));
        }
    };
    return (React.createElement("div", { className: "tensorboard-ng-main" },
        ready && (React.createElement("div", { className: classNames('tensorboard-ng-control-layout', {
                'hide-one': !showNewRow || !showListStatus
            }) },
            React.createElement("div", { className: classNames('tensorboard-ng-control-row', { hide: !showListStatus }) },
                React.createElement("div", { className: "tensorboard-ng-config" },
                    React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                        React.createElement(Button, { className: "refresh-dir-btn", small: true, icon: "refresh", disabled: currentLoading, onClick: refreshRunning }),
                        React.createElement(ModelSelector, { className: "tb-ng-model-selector", popoverProps: { minimal: true }, itemRenderer: (model, { handleClick }) => {
                                return (React.createElement(MenuItem, { key: model.name, onClick: handleClick, text: getShowName(model) }));
                            }, items: runningTensorBoards, onItemSelect: model => changeModel(model), filterable: false, activeItem: currentTensorBoard, disabled: currentLoading },
                            React.createElement(Button, { className: "selector-active-btn", rightIcon: "caret-down", text: React.createElement("span", { className: "active-btn-text" }, currentTensorBoard ? getShowName(currentTensorBoard) : 'NONE'), small: true })),
                        React.createElement(Button, { className: "refresh-dir-btn", small: true, icon: "document-open", disabled: currentLoading, onClick: openInNewTab }),
                        currentTensorBoard && (React.createElement("p", { className: "reload-tip" },
                            "reload interval(s): ",
                            (currentTensorBoard === null || currentTensorBoard === void 0 ? void 0 : currentTensorBoard.reload_interval) || 'Never')))),
                React.createElement("div", { className: "tensorboard-ng-expand" }),
                React.createElement("div", { className: "tensorboard-ng-ops" },
                    React.createElement(Button, { small: true, intent: "primary", className: "tensorboard-ng-op-btn", onClick: reloadTensorBoard, disabled: currentLoading }, "Reload"),
                    React.createElement(Button, { small: true, intent: "danger", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: destroyTensorBoard, title: "Destroy current tensorboard, sidebar `running terminals and kernels` supports destroy all" }, "Destroy"),
                    React.createElement(Button, { small: true, intent: "none", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: copyTensorBoard }, "Duplicate"),
                    React.createElement(Button, { small: true, intent: "none", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: toggleNewRow, active: showNewRow }, "New.."))),
            React.createElement("div", { className: classNames('tensorboard-ng-control-row creator', { hide: !showNewRow }) },
                React.createElement(TensorboardCreator, { disable: currentLoading, getCWD: props.getCWD, startTensorBoard: startTensorBoard, openDoc: props.openDoc }),
                React.createElement("div", { className: "tensorboard-ng-expand" })))),
        React.createElement("div", { className: "tensorboard-ng-iframe-container" },
            currentTensorBoard && (React.createElement("iframe", { sandbox: "allow-scripts allow-forms allow-same-origin", referrerPolicy: "no-referrer", className: 'tensorboard-ng-iframe', src: Tensorboard.getUrl(currentTensorBoard.name) })),
            !currentTensorBoard && (React.createElement("div", { className: "tensorboard-ng-iframe-tip" }, getBlankContent())),
            notActiveError && (React.createElement("div", { className: "tensorboard-ng-iframe-tip" },
                React.createElement("p", { className: "error" }, "Current Tensorboard is not active. Please select others or create a new one."))))));
};

==> jupyterlab_tensorboard_pro-0.7.2.tgz: package/lib/biz/tab.js <==
import React, { useState, useEffect, useRef } from 'react';
import { Button } from '@blueprintjs/core/lib/esm/components/button/buttons';
import { MenuItem } from '@blueprintjs/core/lib/esm/components/menu/menuItem';
import { InputGroup } from '@blueprintjs/core/lib/esm/components/forms/inputGroup';
import { Switch } from '@blueprintjs/core/lib/esm/components/forms/controls';
import { Tag } from '@blueprintjs/core/lib/esm/components/tag/tag';
import { toArray } from '@lumino/algorithm';
import classNames from 'classnames';
import { Select } from '@blueprintjs/select';
import { showDialog, Dialog } from '@jupyterlab/apputils';
import { Loading } from './loading';
import { Tensorboard } from '../tensorboard';
import { DEFAULT_REFRESH_INTERVAL } from '../consts';
const TensorboardCreator = (props) => {
    const [logDir, setLogDir] = useState(props.getCWD());
    const [reloadInterval, setReloadInterval] = useState(DEFAULT_REFRESH_INTERVAL);
    const [enableReloadInterval, setEnableReloadInterval] = useState(false);
    const [enableMultiLog, setEnableMultiLog] = useState(false);
    return (React.createElement("div", { className: "tensorboard-ng-creator" },
        React.createElement("div", { className: "tensorboard-ng-config" },
            React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                React.createElement("label", { title: "Path relative to workspace, don\\'t start with `/`" },
                    React.createElement("strong", null, "Log Dir")),
                React.createElement(InputGroup, { style: { width: 160 }, small: true, placeholder: "Enter your log dir...", value: logDir, onChange: e => {
                        setLogDir(e.target.value);
                        if (e.target.value.includes(',')) {
                            setEnableMultiLog(true);
                        }
                    } })),
            React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                React.createElement(Switch, { className: "multi-log-switch", checked: enableMultiLog, onChange: () => {
                        setEnableMultiLog(!enableMultiLog);
                    }, labelElement: React.createElement("strong", { title: "Use `--logdir_spec` instead of `--logdir` to support multi log dirs, This flag is discouraged and can usually be avoided. for finer-grained control, prefer using a symlink tree. Some features may not work when using `--logdir_spec` instead of `--logdir`" }, "Multi LogDir") }),
                React.createElement(Switch, { className: "interval-switch", checked: enableReloadInterval, onChange: () => {
                        setEnableReloadInterval(!enableReloadInterval);
                    }, labelElement: React.createElement("strong", { title: "Setting reload interval may cause additional burden on the jupyter backend" }, "Reload Interval") }),
                enableReloadInterval && (React.createElement(InputGroup, { style: { width: 80 }, small: true, placeholder: "Enter your reload_interval ...", value: enableReloadInterval ? `${reloadInterval}` : '', onChange: e => {
                        setReloadInterval(Number(e.target.value));
                    }, rightElement: React.createElement(Tag, { minimal: true }, "s"), type: "number" })))),
        React.createElement("div", { className: "tensorboard-ng-ops create" },
            React.createElement(Button, { small: true, intent: "warning", className: "tensorboard-ng-op-btn", onClick: () => {
                    props.startTensorBoard(logDir, enableReloadInterval ? reloadInterval : 0, enableMultiLog);
                }, disabled: props.disable }, "Create TensorBoard")),
        React.createElement("div", { className: "tensorboard-ng-expand" }),
        React.createElement(Button, { small: true, outlined: true, icon: "help", onClick: () => {
                props.openDoc();
            } }, "Document")));
};
const ModelSelector = Select.ofType();
const useRefState = (initValue) => {
    const [value, setValue] = useState(initValue);
    const valueRef = useRef(value);
    const updateValue = (value) => {
        setValue(value);
        valueRef.current = value;
    };
    return [value, valueRef, updateValue];
};
export const TensorboardTabReact = (props) => {
    const [ready, readyRef, updateReady] = useRefState(false);
    const [createPending, createPendingRef, updateCreatePending] = useRefState(false);
    const [reloadPending, reloadPendingRef, updateReloadPending] = useRefState(false);
    const [showNewRow, setShowNewRow] = useState(false);
    const [showListStatus, setShowListStatus] = useState(false);
    const [currentTensorBoard, setCurrentTensorBoard] = useState(null);
    const currentTensorBoardRef = useRef(currentTensorBoard);
    const updateCurrentTensorBoard = (model) => {
        props.updateCurrentModel(model);
        setCurrentTensorBoard(model);
        currentTensorBoardRef.current = model;
    };
    const [runningTensorBoards, setRunningTensorBoards] = useState([]);
    // currently inactive
    const [notActiveError, setNotActiveError] = useState(false);
    const currentLoading = reloadPending || createPending;
    const refreshRunning = () => {
        if (createPendingRef.current || reloadPendingRef.current) {
            return;
        }
        props.tensorboardManager.refreshRunning().then(() => {
            const runningTensorboards = [...toArray(props.tensorboardManager.running())];
            // hint: Using runningTensorboards directly may cause setState to fail to respond
            const modelList = [];
            for (const model of runningTensorboards) {
                modelList.push(model);
            }
            setRunningTensorBoards(modelList);
            if (readyRef.current) {
                // 如果不是第一次了
                if (currentTensorBoardRef.current) {
                    if (!modelList.find(model => model.name === currentTensorBoardRef.current.name)) {
                        setNotActiveError(true);
                    }
                }
                else {
                    // do nothing
                    // Maybe not at the beginning, the user planned to create a new one later, and then did not create a new one. At this time, he found that there was
                }
                return;
            }
            const model = props.createdModelName
                ? modelList.find(model => model.name === props.createdModelName)
                : null;
            if (model) {
                // if createdModelName exist，maybe from Sidebar kernels tab
                updateCurrentTensorBoard(model);
                setShowListStatus(true);
                if (props.setWidgetName) {
                    props.setWidgetName(`${model.name}:` + props.tensorboardManager.formatDir(model.logdir));
                }
            }
            else {
                setShowNewRow(true);
                setShowListStatus(false);
            }
            updateReady(true);
        });
    };
    const startTensorBoard = (logDir, reloadInterval, enableMultiLog) => {
        if (Number.isNaN(reloadInterval) || reloadInterval < 0) {
            return showDialog({
                title: 'Param Check Failed',
                body: 'reloadInterval should > 0 when enabled',
                buttons: [Dialog.okButton()]
            });
        }
        updateCreatePending(true);
        const currentName = currentTensorBoard === null || currentTensorBoard === void 0 ? void 0 : currentTensorBoard.name;
        props
            .startNew(logDir, reloadInterval, enableMultiLog)
            .then(tb => {
            if (currentName === tb.model.name) {
                showDialog({
                    body: 'Existing tensorBoard for the logDir will be reused directly',
                    buttons: [Dialog.okButton()]
                });
            }
            if (props.setWidgetName) {
                props.setWidgetName(`${tb.model.name}:` + props.tensorboardManager.formatDir(tb.model.logdir));
            }
            updateCurrentTensorBoard(tb.model);
            updateCreatePending(false);
            refreshRunning();
            setShowListStatus(true);
            setShowNewRow(false);
        })
            .catch(e => {
            showDialog({
                body: 'Start TensorBoard internal error',
                buttons: [Dialog.okButton()]
            });
        });
    };
    // hint: Because we are simulating reload here, the tab component cannot listen to runningChanged
    const reloadTensorBoard = () => {
        // There was no reload in the world, so I had to stop and restart to simulate reload
        if (!currentTensorBoard) {
            return;
        }
        updateReloadPending(true);
        updateCurrentTensorBoard(null);
        const reloadInterval = typeof currentTensorBoard.reload_interval === 'number'
            ? currentTensorBoard.reload_interval
            : DEFAULT_REFRESH_INTERVAL;
        const currentLogDir = currentTensorBoard.logdir;
        const enableMultiLog = currentTensorBoard.enable_multi_log;
        const errorCallback = (e) => {
            showDialog({
                title: 'TensorBoard Reload Error',
                body: 'The panel has been closed, you can reopen to create new',
                buttons: [Dialog.okButton()]
            });
            props.closeWidget();
        };
        try {
            props.tensorboardManager
                .shutdown(currentTensorBoard.name)
                .then(res => {
                props.tensorboardManager
                    .startNew(currentLogDir, reloadInterval, enableMultiLog)
                    .then(res => {
                    refreshRunning();
                    updateReloadPending(false);
                    updateCurrentTensorBoard(currentTensorBoard);
                })
                    .catch(e => {
                    errorCallback(e);
                });
            })
                .catch(e => {
                errorCallback(e);
            });
        }
        catch (e) {
            errorCallback(e);
        }
    };
    const destroyTensorBoard = () => {
        if (!currentTensorBoard) {
            return;
        }
        props.tensorboardManager.shutdown(currentTensorBoard.name).then(res => {
            props.closeWidget();
        });
    };
    const copyTensorBoard = () => {
        if (!currentTensorBoard) {
            return;
        }
        props.openTensorBoard(currentTensorBoard.name, true);
    };
    const getShowName = (model) => {
        const formattedDir = props.tensorboardManager.formatDir(model.logdir);
        return `${model.name} - ${formattedDir}`;
    };
    const changeModel = (model) => {
        if ((currentTensorBoard === null || currentTensorBoard === void 0 ? void 0 : currentTensorBoard.name) === model.name) {
            return;
        }
        if (props.setWidgetName) {
            props.setWidgetName(`${model.name}:` + props.tensorboardManager.formatDir(model.logdir));
        }
        setCurrentTensorBoard(model);
    };
    const toggleNewRow = () => {
        setShowNewRow(!showNewRow);
    };
    const openInNewTab = () => {
        if (!currentTensorBoard) {
            return;
        }
        window.open(Tensorboard.getUrl(currentTensorBoard.name));
    };
    useEffect(() => {
        refreshRunning();
        const refreshIntervalId = setInterval(refreshRunning, 30 * 1000);
        return () => {
            clearInterval(refreshIntervalId);
        };
    }, []);
    const getBlankContent = () => {
        if (!ready) {
            return React.createElement(Loading, { title: "initializing" });
        }
        else if (createPending) {
            return (React.createElement(Loading, { title: "TensorBoard is initializing", desc: "This stage may take a long time (the more content in the directory, the longer it will be)" }));
        }
        else if (reloadPending) {
            return (React.createElement(Loading, { title: "TensorBoard is reloading", desc: "This stage may take a long time (the more content in the directory, the longer it will be)" }));
        }
        else {
            return (React.createElement("div", { className: "common-tip" },
                React.createElement("p", { className: "title" }, "No instance for current directory yet, please create a new TensorBoard"),
                React.createElement("p", { className: "desc" },
                    React.createElement("i", null, "If the selected log directory has too much content, tensorboard initialization may take a long time, during which jupyter will get stuck"))));
        }
    };
    return (React.createElement("div", { className: "tensorboard-ng-main" },
        ready && (React.createElement("div", { className: classNames('tensorboard-ng-control-layout', {
                'hide-one': !(showNewRow && showListStatus)
            }) },
            React.createElement("div", { className: classNames('tensorboard-ng-control-row', { hide: !showListStatus }) },
                React.createElement("div", { className: "tensorboard-ng-config" },
                    React.createElement("div", { className: "input-container tensorboard-ng-logdir" },
                        React.createElement(Button, { className: "refresh-dir-btn", small: true, icon: "refresh", disabled: currentLoading, onClick: refreshRunning }),
                        React.createElement(ModelSelector, { className: "tb-ng-model-selector", popoverProps: { minimal: true }, itemRenderer: (model, { handleClick }) => {
                                return (React.createElement(MenuItem, { key: model.name, onClick: handleClick, text: getShowName(model) }));
                            }, items: runningTensorBoards, onItemSelect: model => changeModel(model), filterable: false, activeItem: currentTensorBoard, disabled: currentLoading },
                            React.createElement(Button, { title: currentTensorBoard ? getShowName(currentTensorBoard) : 'NONE', className: "selector-active-btn", rightIcon: "caret-down", text: React.createElement("span", { className: "active-btn-text" }, currentTensorBoard ? getShowName(currentTensorBoard) : 'NONE'), small: true })),
                        React.createElement(Button, { className: "refresh-dir-btn", small: true, icon: "document-open", disabled: currentLoading, onClick: openInNewTab }),
                        currentTensorBoard && currentTensorBoard.enable_multi_log && (React.createElement("p", { className: "multi-log-tip" }, "Multi LogDir")),
                        currentTensorBoard && (React.createElement("p", { className: "reload-tip" },
                            "reload interval(s): ",
                            (currentTensorBoard === null || currentTensorBoard === void 0 ? void 0 : currentTensorBoard.reload_interval) || 'Never')))),
                React.createElement("div", { className: "tensorboard-ng-expand" }),
                React.createElement("div", { className: "tensorboard-ng-ops" },
                    React.createElement(Button, { small: true, intent: "primary", className: "tensorboard-ng-op-btn", onClick: reloadTensorBoard, disabled: currentLoading }, "Reload"),
                    React.createElement(Button, { small: true, intent: "danger", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: destroyTensorBoard, title: "Destroy current tensorboard, sidebar `running terminals and kernels` supports destroy all" }, "Destroy"),
                    React.createElement(Button, { small: true, intent: "none", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: copyTensorBoard }, "Duplicate"),
                    React.createElement(Button, { small: true, intent: "none", disabled: currentLoading, className: "tensorboard-ng-op-btn", onClick: toggleNewRow, active: showNewRow }, "New.."))),
            React.createElement("div", { className: classNames('tensorboard-ng-control-row creator', { hide: !showNewRow }) },
                React.createElement(TensorboardCreator, { disable: currentLoading, getCWD: props.getCWD, startTensorBoard: startTensorBoard, openDoc: props.openDoc }),
                React.createElement("div", { className: "tensorboard-ng-expand" })))),
        React.createElement("div", { className: "tensorboard-ng-iframe-container" },
            currentTensorBoard && (React.createElement("iframe", { sandbox: "allow-scripts allow-forms allow-same-origin", referrerPolicy: "no-referrer", className: 'tensorboard-ng-iframe', src: Tensorboard.getUrl(currentTensorBoard.name) })),
            !currentTensorBoard && (React.createElement("div", { className: "tensorboard-ng-iframe-tip" }, getBlankContent())),
            notActiveError && (React.createElement("div", { className: "tensorboard-ng-iframe-tip" },
                React.createElement("p", { className: "error" }, "Current Tensorboard is not active. Please select others or create a new one."))))));
};
